summaryrefslogtreecommitdiffstats
path: root/karbon/core/vlayer.h
diff options
context:
space:
mode:
Diffstat (limited to 'karbon/core/vlayer.h')
-rw-r--r--karbon/core/vlayer.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/karbon/core/vlayer.h b/karbon/core/vlayer.h
index 26524416..7dbd126b 100644
--- a/karbon/core/vlayer.h
+++ b/karbon/core/vlayer.h
@@ -22,7 +22,7 @@
#include "vgroup.h"
#include <koffice_export.h>
-class QDomElement;
+class TQDomElement;
class DCOPObject;
@@ -37,12 +37,12 @@ class KARBONBASE_EXPORT VLayer : public VGroup
{
public:
/**
* Constructs a new layer object that is child of parent and has the given state.
*
* @param parent the new object's parent
* @param state the new object's state
*/
- VLayer( VObject* parent, VState state = normal );
+ VLayer( VObject* tqparent, VState state = normal );
/**
* Copy constructor.
@@ -56,9 +56,9 @@ public:
virtual void draw( VPainter *painter, const KoRect* rect = 0L ) const;
- virtual void save( QDomElement& element ) const;
+ virtual void save( TQDomElement& element ) const;
virtual void saveOasis( KoStore *store, KoXmlWriter *docWriter, KoGenStyles &mainStyles, int &index ) const;
- virtual void load( const QDomElement& element );
+ virtual void load( const TQDomElement& element );
virtual VLayer* clone() const;
@@ -37,12 +37,12 @@ class KARBONBASE_EXPORT VLayer : public VGroup
public:
/**
- * Constructs a new layer object that is child of parent and has the given state.
+ * Constructs a new layer object that is child of tqparent and has the given state.
*
@@ -37,12 +37,12 @@ class KARBONBASE_EXPORT VLayer : public VGroup
*
- * @param parent the new object's parent
+ * @param tqparent the new object's tqparent
* @param state the new object's state
*/